# WAFFLE
Workflow and Automatic Figures For Large Ensembles (WAFFLE) is a toolkit readily generating matplotlib figures using a set standardized configurations commonly used in the analysis of climate model output.
